#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.11.1
visibility:           public
id:                   floskell-0.11.1-HsKP7puYzgKA0O2JSq4vWX
key:                  floskell-0.11.1-HsKP7puYzgKA0O2JSq4vWX
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  862d306125c5ee6e8e8605c5b394929d
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/floskell-0.11.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/floskell-0.11.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/floskell-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.11.1-HsKP7puYzgKA0O2JSq4vWX
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX
    attoparsec-aeson-2.2.2.0-3K5rvkmbaC6GALCK495q1W base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    filepath-1.4.300.1 haskell-src-exts-1.23.1-7Kw9ReAvtGxEpX84ChnpH
    monad-dijkstra-0.1.1.5-3XbbNLvugRqDW2Cc7phYHj mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

